#!/usr/bin/env python

import os, sys
import time
import subprocess as sp
from zlib import crc32
from hashlib import sha256
import shlex
import traceback
import re

def clean_maps():
    path = ".\\downloadedmaps"
    try:
        cwd = os.getcwd()
        os.chdir(path)
        _clean_maps()
    except KeyboardInterrupt:
        pass
    except:
        exc_type, exc_value, exc_traceback = sys.exc_info()
        traceback.print_exception(exc_type, exc_value, exc_traceback)
    finally:
        os.chdir(cwd)

def _clean_maps():
    maps = os.listdir()

    clean = []

    for file in maps:
        if os.path.islink(file):
            continue
        with open(file, 'rb') as f:
            rawbytes = f.read()
            longchk = "_"+sha256(rawbytes).hexdigest()
            shortchk = "_{:x}".format(crc32(rawbytes))
            ##print(file, shortchk, longchk)
            mapname = file.replace(longchk, "").replace(shortchk, "").replace('.map', '')

        mapname256 = mapname + longchk + ".map"
        mapname32 = mapname + shortchk + ".map"

        if file != mapname256:
            print("Moving {} to {}".format(file, mapname256))
            os.replace(file, mapname256)
        if not os.path.exists(mapname32):
            print("Creating symlink {} --> {}".format(mapname32, mapname256))
            cmd = r'''cmd /c mklink "{}" "{}" '''.format(mapname32, mapname256)
            print('Running command:', cmd)
            print('Running command:', shlex.split(cmd))
            sp.run(shlex.split(cmd), shell=True)
        del mapname256, mapname32
    
def clean_demos():
    path = ".\\demos\\auto\\race"
    demos = os.listdir(path)

    for demo in demos:
        if '_tmp' in demo:
            print('Deleted ', demo)
##            os.remove(path+'\\'+demo)
        

clean_demos()
clean_maps()
        
